@@ -10,10 +10,10 @@ class SFTPManager:
     self.username = username
     self.password = password
     self.privateKey = privateKey
-  
+
     self.cnopts = pysftp.CnOpts()
     self.cnopts.hostkeys = None
-  
+
   def create_connection(self):
     try:
       if self.privateKey is not None:
@@ -33,7 +33,7 @@ class SFTPManager:
       logger.error(e)
       raise e
 
-  def list_files_in_path(self, remotePath:str) -> list:
+  def list_files_in_path(self, remotePath:str = '.') -> list:
     """Get list of filenames in the given remote directory
 
     Args:
@@ -44,13 +44,13 @@ class SFTPManager:
 
     Returns:
         list: List of filenames found in remotePath
-    """    
+    """
     try:
-      return list(self.sftp.listdir())
+      return list(self.sftp.listdir(remotePath))
     except Exception as e:
       logger.error(e)
       raise e
-    
+
   def download_file(self, remoteFilename:str, localFilename:str):
     """Download file from remote directory to local directory
 
@@ -60,7 +60,7 @@ class SFTPManager:
 
     Raises:
         Exception: if failed to connect to SFTP server
-    """    
+    """
     try:
       self.sftp.get(remoteFilename, localFilename)
     except Exception as e:
@@ -78,7 +78,7 @@ class SFTPManager:
 
     Returns:
         List[str]: list of path_to_downloaded_files
-    """    
+    """
     files = []
     for eachFile in filesInDir:
       filename, fileExtension = os.path.splitext(eachFile)
@@ -110,13 +110,13 @@ class SFTPManager:
 
     Returns:
         list: list of path_to_downloaded_files
-    """    
+    """
     try:
       self.__downloadDir__(self.sftp, self.list_files_in_path(remotePath), localPath, filterOptions)
     except Exception as e:
       logger.error(e)
       raise e
-  
+
   def upload_file(self, localFilename:str, remoteFilename:str):
     """Upload local file to SFTP server
 
@@ -126,13 +126,13 @@ class SFTPManager:
 
     Raises:
         Exception: if failed to connect to SFTP server
-    """    
+    """
     try:
       self.sftp.put(localFilename, remoteFilename)
     except Exception as e:
       logger.error(e)
       raise e
-  
+
   def delete_file(self, remoteFilename:str):
     """delete a specific file in SFTP server
 
@@ -141,7 +141,7 @@ class SFTPManager:
 
     Raises:
         Exception: if fail to connect to SFTP server
-    """    
+    """
     try:
       self.sftp.remove(remoteFilename)
     except Exception as e:
